@@ -3,6 +3,7 @@ from django.conf import settings
 from django.db import models
 from django.utils.safestring import mark_safe
 from django.utils.html import escape
+from django.utils.encoding import python_2_unicode_compatible
 
 from markupfield import widgets
 from markupfield import markup
@@ -14,6 +15,7 @@ _markup_type_field_name = lambda name: '%s_markup_type' % name
 _MARKUP_TYPES = getattr(settings, 'MARKUP_FIELD_TYPES', markup.DEFAULT_MARKUP_TYPES)
 
 
+@python_2_unicode_compatible
 class Markup(object):
 
     def __init__(self, instance, field_name, rendered_field_name,
@@ -49,7 +51,7 @@ class Markup(object):
     rendered = property(_get_rendered)
 
     # allows display via templates to work without safe filter
-    def __unicode__(self):
+    def __str__(self):
         return mark_safe(self.rendered)
 
 
@@ -91,11 +93,9 @@ class MarkupField(models.TextField):
         self.markup_type_editable = markup_type is None
         self.escape_html = escape_html
 
-        # pre 1.0 markup_choices might have been a dict
+        # pre-1.0 markup_choices might have been a dict
         if isinstance(markup_choices, dict):
-            raise DeprecationWarning('passing a dictionary as markup_choices is deprecated')
-            self.markup_choices_dict = markup_choices
-            self.markup_choices_list = markup_choices.keys()
+            raise ValueError('passing a dict as markup_choices removed in 1.1')
         else:
             self.markup_choices_list = [mc[0] for mc in markup_choices]
             self.markup_choices_dict = dict(markup_choices)
