@@ -1,3 +1,5 @@
+from __future__ import unicode_literals
+
 from django.utils.html import linebreaks, urlize
 from django.utils.functional import curry
 from django.conf import settings
@@ -32,7 +34,7 @@ try:
                 # no lexer found - use the text one instead of an exception
                 lexer = TextLexer()
             formatter = options and VARIANTS[options.keys()[0]] or DEFAULT
-            parsed = highlight(u'\n'.join(content), lexer, formatter)
+            parsed = highlight('\n'.join(content), lexer, formatter)
             return [nodes.raw('', parsed, format='html')]
         pygments_directive.arguments = (1, 0, 1)
         pygments_directive.content = 1
